#[unsafe(no_mangle)]pub extern "C" fn laminar_clear_error()Expand description
Clear the last error.
Call this to reset error state before a sequence of operations.
#[unsafe(no_mangle)]pub extern "C" fn laminar_clear_error()Clear the last error.
Call this to reset error state before a sequence of operations.