#[unsafe(no_mangle)]pub unsafe extern "C" fn laminar_schema_field_name(
schema: *mut LaminarSchema,
index: usize,
out: *mut *mut c_char,
) -> i32Expand description
Get the name of a field by index.
Arguments
schema- Schema handleindex- Field index (0-based)out- Pointer to receive field name (caller frees withlaminar_string_free)
Returns
LAMINAR_OK on success, or an error code.
Safety
schemamust be a valid schema handleindexmust be less than the number of fieldsoutmust be a valid pointer