#[unsafe(no_mangle)]pub unsafe extern "C" fn laminar_subscription_user_data(
handle: *mut LaminarSubscriptionHandle,
) -> *mut c_voidExpand description
Return the user data pointer from a subscription handle, or NULL.
Safety
handle must be a valid subscription handle or NULL.