#[unsafe(no_mangle)]pub unsafe extern "C" fn laminar_batch_import(
array: *mut FFI_ArrowArray,
schema: *mut FFI_ArrowSchema,
out: *mut *mut LaminarRecordBatch,
) -> i32Expand description
Import a RecordBatch from the Arrow C Data Interface, taking ownership of both structs.
Safety
array, schema, and out must be valid non-null pointers;
ownership of array and schema is transferred and they are released by this function.