pub type LaminarSubscriptionCallback = Option<unsafe extern "C" fn(user_data: *mut c_void, batch: *mut LaminarRecordBatch, event_type: i32)>;Expand description
Callback invoked from the subscription thread with each batch.
Safety
The callback receives ownership of batch and must free it with laminar_batch_free.
Aliased Type
pub enum LaminarSubscriptionCallback {
None,
Some(unsafe extern "C" fn(*mut c_void, *mut LaminarRecordBatch, i32)),
}