pub struct TieringConfig {
pub hot_class: String,
pub warm_class: String,
pub cold_class: String,
pub hot_retention_secs: u64,
pub warm_retention_secs: u64,
}Expand description
S3 storage class tiering configuration.
Controls how checkpoint objects are assigned to S3 storage classes for cost optimization. Active checkpoints use the hot tier (fast access), older checkpoints are moved to warm/cold tiers via S3 Lifecycle rules.
Fields
hot_class: StringStorage class for active checkpoints (e.g., "EXPRESS_ONE_ZONE", "STANDARD").
warm_class: StringStorage class for older checkpoints (e.g., "STANDARD").
cold_class: StringStorage class for archive checkpoints (e.g., "GLACIER_IR"). Empty = no cold tier.
hot_retention_secs: u64Time before moving objects from hot to warm tier (seconds).
warm_retention_secs: u64Time before moving objects from warm to cold tier (seconds). 0 = no cold tier.